==> nextcloud-app-tasks-0.11.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/is.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Verkefni",
    "Important" : "Mikilvægt",
    "Today" : "Í dag",
    "Week" : "Vika",
    "All" : "Allt",
    "Current" : "Núverandi",
    "Completed" : "Lokið",
    "The Tasks app for Nextcloud" : "Verkefnaforrit fyrir Nextcloud",
    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates, reminder times, mark them as important, and add comments on them. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal... - just add the calendar as a remote calendar in you client). You can download your tasks as ICS files using the download button for each calendar." : "Þegar þetta hefur verið virkjað birtist ný Verkefni-valmynd í Nextcloud-forritavalmyndinni. Þaðan er hægt að bæta við og eyða verkefnum, breyta fyrirsögn þeirra, lýsingu, upphafs- og lokadagsetningum, tímasetningum áminninga, merkja sem mikilvæg og bæta athugasemdum við verk. Hægt er að seila verkefnum á milli notenda. Verkefni er hægt að samstilla með CalDav (hver verkefnalisti er tendur við Nextcloud-dagatal, til að samstilla það við dagatalatengd forrit - Thunderbird, Evolution, KDE Kontact, iCal... - þarf einfaldlega að bæta dagatalinu við sem fjartengdu dagatali í forritinu). Þú getur sótt verkefnin þín sem ICS-skrár með því að ýta á niðurhalshnappinn við hvert dagatal.",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "No users or groups" : "Engir notendur eða hópar",
    "can edit" : "getur breytt",
    "Unable to delete the share." : "Get ekki eytt sameigninni.",
    "Unable to change permissions." : "Tekst ekki að breyta heimildum.",
    "Delete" : "Eyða",
    "Cancel" : "Hætta við",
    "Delete all completed tasks." : "Eyða öllum loknum verkum.",
    "Delete completed tasks." : "Eyða loknum verkum.",
    "No errors" : "Engar villur",
    "Open your browser console for more details" : "Opnaðu stjórnborð vafrans þíns til að sjá frekari upplýsingar",
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Gat ekki eytt {failedCount} verkefni.","Gat ekki eytt {failedCount} verkefnum."],
    "Load all completed tasks." : "Hlaða inn öllum loknum verkum.",
    "Change sort order" : "Breyta röðun",
    "Default" : "Sjálfgefið",
    "Sort by completed state, due date, priority, start date and summary." : "Raða eftir framvindustöðu, skiladegi, forgangi, upphafsdagsetningu og yfirliti.",
    "Due date" : "Skiladagur",
    "Sort by due date and summary." : "Raða eftir skiladagsetningu og yfirliti.",
    "Start date" : "Upphafsdagur",
    "Sort by start date and summary." : "Raða eftir upphafsdagsetningu og yfirliti.",
    "Created date" : "Búið til",
    "Sort by created date and summary." : "Raða eftir dagsetningu þegar var útbúið og yfirliti.",
    "Last modified" : "Síðast breytt",
    "Sort by last-modified date and summary." : "Raða eftir dagsetningu þegar var síðast breytt og yfirliti.",
    "Completed date" : "Lokadagsetning",
    "Sort by completed date." : "Raða eftir lokadagsetningu",
    "Priority" : "Forgangur",
    "Sort by priority and summary." : "Raða eftir forgangi og yfirliti.",
    "Manually" : "Handvirkt",
    "Sort by manual order." : "Raða eftir handvirkri röð.",
    "Alphabetically" : "Í stafrófsröð",
    "Sort by summary and priority." : "Raða eftir yfirliti og forgangi.",
    "Task is completed" : "Verkefni er lokið",
    "{complete} % completed" : "{complete} % lokið",
    "Toggle visibility of completed subtasks." : "Víxla sýnileika allra lokinna undirverkefna.",
    "Toggle visibility of all subtasks." : "Víxla sýnileika allra undirverkefna.",
    "[Yesterday]" : "[Í gær]",
    "[Today]" : "[Í dag]",
    "[Tomorrow]" : "[Á morgun]",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lokið verkefni","%n lokin verkefni"],
    "Tomorrow" : "Á morgun",
    "Set start date" : "Setja upphafsdag",
    "Set start time" : "Setja upphafstíma",
    "Set due date" : "Setja skiladag",
    "Set due time" : "Setja skilatíma",
    "All day" : "Heilsdagsviðburður",
    "Select a calendar" : "Veldu dagatal",
    "Select a classification" : "Veldu flokkun",
    "Select categories" : "Veldu flokka",
    "Add this as a new category" : "Bæta þessu við sem nýjum flokki",
    "Task not found!" : "Verkefn fannst ekki!",
    "[Starts today]" : "[Byrjar í dag]",
    "[Starts tomorrow]" : "[Byrjar á morgun]",
    "[Starts on] LL" : "[Byrjar þann] LL",
    "[Started yesterday]" : "[Byrjaði í gær]",
    "[Started on] LL" : "[Byrjar þann] LL",
    "[Started today at] LT" : "[Byrjaði í dag klukkan] LT",
    "[Starts today at] LT" : "[Byrjar í dag klukkan] LT",
    "[Starts tomorrow at] LT" : "[Byrjar í á morgun klukkan] LT",
    "[Starts on] LL [at] LT" : "[Byrjar þann] LL [klukkan] LT",
    "[Started yesterday at] LT" : "[Byrjaði í gær klukkan] LT",
    "[Started on] LL [at] LT" : "[Byrjaði þann] LL [klukkan] LT",
    "[Due today]" : "[Á að ljúka í dag]",
    "[Due tomorrow]" : "[Á að ljúka á morgun]",
    "[Due on] LL" : "[Á að ljúka þann] LL",
    "[Was due yesterday]" : "[Átti að ljúka í gær]",
    "[Was due on] LL" : "[Átti að ljúka þann] LL",
    "[Was due today at] LT" : "[Átti að ljúka í dag klukkan] LT",
    "[Due today at] LT" : "[Á að ljúka í dag klukkan] LT",
    "[Due tomorrow at] LT" : "[Á að ljúka á morgun klukkan] LT",
    "[Due on] LL [at] LT" : "[Á að ljúka þann] LL [klukkan] LT",
    "[Was due yesterday at] LT" : "[Átti að ljúka í gær klukkan] LT",
    "[Was due on] LL [at] LT" : "[Átti að ljúka þann] LL [klukkan] LT",
    "No priority assigned" : "Enginn forgangur settur",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "Edit" : "Breyta",
    "Copy private link" : "Afrita einkatengil",
    "Copied" : "Afritað",
    "Can not copy" : "Gat ekki afritað",
    "Download" : "Sækja",
    "Save" : "Vista",
    "Add List…" : "Bæta við lista...",
    "New List" : "Nýr listi",
    "Calendar link copied to clipboard." : "Dagatalstengill afritaður á klippispjald.",
    "Calendar link could not be copied to clipboard." : "Ekki var hægt að afrita dagatalstengil á klippispjald.",
    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Deilt með {num} einindi","Deilt með {num} einindum"],
    "Settings" : "Stillingar",
    "Default list" : "Sjálfgefinn listi",
    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
    "Hidden" : "Falið",
    "Visible" : "Sýnilegt",
    "Automatic" : "Sjálfvirkt",
    "Could not delete the task." : "Gat ekki eytt verkefninu.",
    "Synchronizing to the server." : "Samstilli við netþjóninn.",
    "Task successfully saved to server." : "Tókst að vista verkefnið á þjóninn.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Gat ekki uppfært verkefnið vegna þess að því var breytt á þjóninum. Smelltu til að endurlesa það, breytingum hjá þér verður hent.",
    "Could not update the task." : "Gat ekki uppfært verkefnið.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discared." : "Gat ekki uppfært verkefnið vegna þess að því var breytt á þjóninum. Smelltu til að endurlesa það, breytingum hjá þér verður hent.",
    "An error occurred" : "Villa kom upp"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");

==> nextcloud-app-tasks-0.12.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/is.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "Mikilvægt",
    "Today" : "Í dag",
    "Week" : "Vika",
    "All" : "Allt",
    "Current" : "Núverandi",
    "Completed" : "Lokið",
    "Tasks" : "Verkefni",
    "The Tasks app for Nextcloud" : "Verkefnaforrit fyrir Nextcloud",
    "Share with users or groups" : "Deila með notendum eða hópum",
    "No users or groups" : "Engir notendur eða hópar",
    "can edit" : "getur breytt",
    "Unshare with {displayName}" : "Hætta deilingu með {displayName}",
    "Unable to delete the share." : "Get ekki eytt sameigninni.",
    "Unable to change permissions." : "Tekst ekki að breyta heimildum.",
    "Add List…" : "Bæta við lista...",
    "New List" : "Nýr listi",
    "Cancel" : "Hætta við",
    "Save" : "Vista",
    "An empty name is not allowed." : "Autt heiti er ekki leyft.",
    "Edit" : "Breyta",
    "Copy private link" : "Afrita einkatengil",
    "Copied" : "Afritað",
    "Can not copy" : "Gat ekki afritað",
    "Download" : "Sækja",
    "Delete" : "Eyða",
    "Unshare" : "Hætta deilingu",
    "Calendar link copied to clipboard." : "Dagatalstengill afritaður á klippispjald.",
    "Calendar link could not be copied to clipboard." : "Ekki var hægt að afrita dagatalstengil á klippispjald.",
    "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Deilt með {num} einindi","Deilt með {num} einindum"],
    "Default list" : "Sjálfgefinn listi",
    "Visibility of Smart Collections" : "Sýnileiki snjallsafna (Smart Collections)",
    "Hidden" : "Falið",
    "Visible" : "Sýnilegt",
    "Automatic" : "Sjálfvirkt",
    "Delete all completed tasks." : "Eyða öllum loknum verkum.",
    "Delete completed tasks." : "Eyða loknum verkum.",
    "No errors" : "Engar villur",
    "Open your browser console for more details" : "Opnaðu stjórnborð vafrans þíns til að sjá frekari upplýsingar",
    "_Could not delete {failedCount} task._::_Could not delete {failedCount} tasks._" : ["Gat ekki eytt {failedCount} verkefni.","Gat ekki eytt {failedCount} verkefnum."],
    "Load all completed tasks." : "Hlaða inn öllum loknum verkum.",
    "Change sort order" : "Breyta röðun",
    "Sort by completed state, due date, priority, start date and summary." : "Raða eftir framvindustöðu, skiladegi, forgangi, upphafsdagsetningu og yfirliti.",
    "Start date" : "Upphafsdagur",
    "Sort by start date and summary." : "Raða eftir upphafsdagsetningu og yfirliti.",
    "Due date" : "Skiladagur",
    "Sort by due date and summary." : "Raða eftir skiladagsetningu og yfirliti.",
    "Created date" : "Búið til",
    "Sort by created date and summary." : "Raða eftir dagsetningu þegar var útbúið og yfirliti.",
    "Last modified" : "Síðast breytt",
    "Sort by last-modified date and summary." : "Raða eftir dagsetningu þegar var síðast breytt og yfirliti.",
    "Completed date" : "Lokadagsetning",
    "Sort by completed date." : "Raða eftir lokadagsetningu",
    "Priority" : "Forgangur",
    "Sort by priority and summary." : "Raða eftir forgangi og yfirliti.",
    "Manually" : "Handvirkt",
    "Sort by manual order." : "Raða eftir handvirkri röð.",
    "Alphabetically" : "Í stafrófsröð",
    "Sort by summary and priority." : "Raða eftir yfirliti og forgangi.",
    "Task is completed" : "Verkefni er lokið",
    "{complete} % completed" : "{complete} % lokið",
    "[Yesterday]" : "[Í gær]",
    "[Today]" : "[Í dag]",
    "[Tomorrow]" : "[Á morgun]",
    "Add a subtask to \"{task}\"…" : "Bæta undirverkefni við \"{task}\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n lokið verkefni","%n lokin verkefni"],
    "Add an important task to \"{calendar}\"…" : "Bæta mikilvægu verkefni við \"{calendar}\"...",
    "Add a task due today to \"{calendar}\"…" : "Bæta verkefni sem á að klára í dag við \"{calendar}\"...",
    "Add a current task to \"{calendar}\"…" : "Bæta fyrirliggjandi verkefni við \"{calendar}\"...",
    "Add a task to \"{calendar}\"…" : "Bæta verkefni við \"{calendar}\"...",
    "Tomorrow" : "Á morgun",
    "Set start date" : "Setja upphafsdag",
    "Set start time" : "Setja upphafstíma",
    "Set due date" : "Setja skiladag",
    "Set due time" : "Setja skilatíma",
    "All day" : "Heilsdagsviðburður",
    "Select a calendar" : "Veldu dagatal",
    "Select a classification" : "Veldu flokkun",
    "Select categories" : "Veldu flokka",
    "Add this as a new category" : "Bæta þessu við sem nýjum flokki",
    "Task not found!" : "Verkefn fannst ekki!",
    "When shared show full event" : "Þegar er deilt, birta allan atburð",
    "When shared show only busy" : "Þegar er deilt, birta eingöngu upptekið",
    "When shared hide this event" : "Þegar er deilt, fela þennan atburð",
    "[Starts today]" : "[Byrjar í dag]",
    "[Starts tomorrow]" : "[Byrjar á morgun]",
    "[Starts on] LL" : "[Byrjar þann] LL",
    "[Started yesterday]" : "[Byrjaði í gær]",
    "[Started on] LL" : "[Byrjar þann] LL",
    "[Started today at] LT" : "[Byrjaði í dag klukkan] LT",
    "[Starts today at] LT" : "[Byrjar í dag klukkan] LT",
    "[Starts tomorrow at] LT" : "[Byrjar í á morgun klukkan] LT",
    "[Starts on] LL [at] LT" : "[Byrjar þann] LL [klukkan] LT",
    "[Started yesterday at] LT" : "[Byrjaði í gær klukkan] LT",
    "[Started on] LL [at] LT" : "[Byrjaði þann] LL [klukkan] LT",
    "[Due today]" : "[Á að ljúka í dag]",
    "[Due tomorrow]" : "[Á að ljúka á morgun]",
    "[Due on] LL" : "[Á að ljúka þann] LL",
    "[Was due yesterday]" : "[Átti að ljúka í gær]",
    "[Was due on] LL" : "[Átti að ljúka þann] LL",
    "[Was due today at] LT" : "[Átti að ljúka í dag klukkan] LT",
    "[Due today at] LT" : "[Á að ljúka í dag klukkan] LT",
    "[Due tomorrow at] LT" : "[Á að ljúka á morgun klukkan] LT",
    "[Due on] LL [at] LT" : "[Á að ljúka þann] LL [klukkan] LT",
    "[Was due yesterday at] LT" : "[Átti að ljúka í gær klukkan] LT",
    "[Was due on] LL [at] LT" : "[Átti að ljúka þann] LL [klukkan] LT",
    "No priority assigned" : "Enginn forgangur settur",
    "Could not delete the task." : "Gat ekki eytt verkefninu.",
    "Synchronizing to the server." : "Samstilli við netþjóninn.",
    "Task successfully saved to server." : "Tókst að vista verkefnið á þjóninn.",
    "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "Gat ekki uppfært verkefnið vegna þess að því var breytt á þjóninum. Smelltu til að endurlesa það, breytingum hjá þér verður hent.",
    "Could not update the task." : "Gat ekki uppfært verkefnið.",
    "An error occurred" : "Villa kom upp"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
